#
# spec file for package xfce4-appfinder
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
Name:           xfce4-appfinder
Version:        4.16.1
Release:        bp153.1.15
Summary:        Application Finder for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/xfce/xfce4-appfinder/start
Source:         https://archive.xfce.org/src/xfce/%{name}/4.16/%{name}-%{version}.tar.bz2
BuildRequires:  appstream-glib
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(garcon-1) >= 0.3.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.50
BuildRequires:  pkgconfig(glib-2.0) >= 2.50
BuildRequires:  pkgconfig(gthread-2.0) >= 2.50
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.10.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.15.2
BuildRequires:  pkgconfig(libxfconf-0) >= 4.10.0
# uses exo-open
Requires:       exo-tools
Recommends:     %{name}-lang = %{version}

%description
xfce4-appfinder is an application finder for the Xfce desktop environment. It
is a useful program that allows you to find applications on the system and
launch them. It provides easy keyboard navigation and can be used as a
replacement for xfrun4.

%lang_package

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode
%else
%configure
%endif
%make_build

%install
%make_install

%suse_update_desktop_file %{name} Utility DesktopUtility

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml

%files
%license COPYING
%doc AUTHORS NEWS README.md TODO
%{_bindir}/xfrun4
%{_bindir}/xfce4-appfinder
%{_datadir}/applications/*.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.xfce.xfce4-appfinder.appdata.xml
%{_datadir}/icons/hicolor/*/apps/org.xfce.appfinder.*

%files lang -f %{name}.lang

%changelog
* Mon Jan 18 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.1
  * Launch applications as children again
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  * Launch applications reparenting them to init
  * Bump gtk minimum version to 3.22.0
  * bump glib (and gio, gthread, etc) minimum to 2.50.0
  * Translation Updates
* Tue Oct 27 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.2
  * Add small delay before reloading menu tree
  (gxo#xfce/xfce4-appfinder!6)
  * Clear entry's error icon and tooltip
  * Update copyright year
  * GitLab is the new bugtracker
  * Remove unnecessary code for unsupported glib versions
  * Remove padding from context menu
  * Fix memory leaks when sorting items
  * Update README.md
  * Apply light blue to 16px icon
  * Improved and simplified icons for better scaling
  * Add back git tag
  * Remove extra spaces in configure.ac.in so xfce-do-release works
    as expected
  * Translation Updates
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.1
  * Drop close button
  * Add new app icon and switch to rDNS
  * Limit popup completion width to be same as entry
  * Switch to a few symbolic icons
  * Add keywords to .desktop files to xfce4-appfinder
  * Record last commands only once (bxo#15767)
  * Sort by frecency (bxo#9265)
  * Switch to README.md and foreign automake mode
  * Move from exo-csource to xdt-csource (bxo#16717)
  * Make Preferences button always visible (bxo#16489)
  * Hidden option to disable entry completion (bxo#15827)
  * Use casefolded string when searching for apps not commands
    (bxo#15893)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 4.14.0
  * Replace GtkStock buttons
  * Translation Updates:
- Claned up spec file
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.5
  * Translation updates
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.4
  * Improve xfce4-run comment (bxo#15473)
  * Translation updates
- Validate appstream metadata
* Fri May 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.13.3
  * Update minimal required glib to 2.42
  * Allow case-insensitive search
  * Do not wrap when Text beside icons is enabled (bxo#8490)
  * Icon view: reduce padding/spacing with small icons
  * Translation updates
- Updated dependencies
- Fixed up %%build section
* Tue Apr 30 2019 Vinzenz Vietzke <vinz@vinzv.de>
- update to version 4.13.2
  - Convert AppData file to AppStream (bxo#14624)
  - Improved spacing and resizing (bxo#14651)
  - Ignore menu items without name (bxo#14655)
  - Add hide category preference (bxo#14893)
  - Save command in history even if it matches Exec (bxo#9023)
  - Change default action conflicting pattern (bxo#12103)
  - Translation updates
- Changes from 4.13.1
  - Improved keyboard navigation in List View
  - When expanded, launch apps with single enter press (bxo#14469)
  - Improved app sorting
  - Add single window option
  - Fix segfault when toggling bookmarks (bxo#14134)
  - Fix preferences button height
  - Translation updates
- Changes from 4.13.0
  - Port to GTK+3.
  - Update app icons to new standard names.
  - Fuzzy search matching (bxo#10393).
  - Translation updates
- Clean up spec file:
  - Added conditional %%bcond_with git for easier maintanance when using
    git master branch
  - Updated URL
* Mon Dec 10 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Cleaned up spec file
- BR: Replaced libraries with devel packages
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - fix build problems.
  - add support for AppData
  - translation updates
* Thu May  1 2014 gber@opensuse.org
- update to version 4.11.0
  - make compilation to GTK3 optional
  - use GDbus for communication
  - add execute menu item to launch without closing the window
  - add default action to open absolute paths
  - add bookmarks in the model
  - do nothing with the Tab event during competion (bxo#10187)
  - use new xdg function to set environment
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 4.10.1
  - use new glib 2.32 api
  - autotools updates
  - detach from icon theme to avoid segfault
  - protect against possible null pointers
  - translation updates
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - add a valid category to xfce4-run.desktop
  - fix property-changed matching
  - avoid a single category if the root menu has a directory
  - avoid segfault when right-clicking a custom command
  - only focus view if an item is selected on entry active
  - try to spawn a custom command in expanded view as well
  - translation updates
- depend on exo-tools since it uses exo-open
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.5
  - don't use deprecated g_mapped_file_free
  - bump gtk, glib and xfce dependencies
  - make launch button translatable
  - translation updates
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.4
  - add Help button to preferences dialog
  - make sure the header icon does not shrink
  - set single line label for icon sizes < "small"
  - add option to disable the background service
  - block maximize and fullscreen in collapsed mode
  - chain-up unmap
  - start in collapsed mode if xfrun4 symlink is used
  - select entry when Ctrl+L is pressed
  - quit the mainloop when receiving an exit signal
  - avoid xfconf error when closing windows on quit
  - add icon view mode and add preferences to set icon sizes
  - only show categories with items
  - add keybinds to switch modes (Ctrl-1 and Ctrl-2)
  - improve reloading of items and directories
  - add popup menu to edit, hide and revert desktop files
  - add refcount debugging
  - remove xfrun from the utility menu
  - fix some segfaults
  - add option to save custom command matches
  - insert and reload history command in model
  - change treeview filter prio to avoid window resize
  - add left/right navigation to the treeviews
  - add a custom completion match function
  - use long option, looks better in code completion
  - drop usage of new Gdk keycode api
  - fix launching in collapsed mode
  - don't ignore arguments of the desktop file command
  - always allow up/down unless the completion menu is shown
  - fix segfault when loading default actions
  - rewrite of the the application finder to merge the
    functionality of the appfinder as we know it in 4.8 and xfrun4
    (start with --collapsed)
  - Translation updates
* Thu Mar 29 2012 gber@opensuse.org
- split off -lang subpackage
- corrected dependencies
- specfile cleanup
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  - no changes
* Sun Dec 26 2010 gber@opensuse.org
- corrected license
- improved summary/description
- dropped unnecessary build dependencies
- show compiler output
- remove unsupported locales
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Sun Jul 18 2010 bernhard@bwalle.de
- updated to 4.6.2
  o Build fixes for GIT.
  o Properly propagate the focus-in-event of the search entry (bug #5883).
  o Translation updates (es, gl, hu, id, it, pl, pt, tr, lv, ur, ur_PK,
    ro, sq, sk, nl, kk, ug).
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Wed Oct 29 2008 bwalle@suse.de
- update to 4.4.3
  * polished translations
* Tue Dec  4 2007 prusnak@suse.cz
- use %%find_lang macro
- do not package INSTALL file
* Mon Dec  3 2007 bwalle@suse.de
- update to 4.4.2
  o Remove trailing parens on AC_INIT version info to work around
    bug in intltool 0.35.x and 0.36.x.
  o Updated and new translations
* Sun Oct 21 2007 bwalle@suse.de
- changed group to 'System/GUI/XFCE'
* Tue May 22 2007 prusnak@suse.cz
- removed X-SuSE-translate from desktop file
* Tue Apr 10 2007 bwalle@suse.de
- update to 4.4.1
  o Many translation updates.
* Thu Jan 25 2007 bwalle@suse.de
- removed /usr/share/locale/hy
* Sun Jan 21 2007 bwalle@suse.de
- upgraded to 4.4.0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 pnemec@suse.cz
- update to 4.2.3
* Wed Sep 14 2005 cthiel@suse.de
- specfile cleanup
* Mon Aug  1 2005 cthiel@suse.de
- fixed Requires
* Wed May 18 2005 cthiel@suse.de
- update to 4.2.2
* Tue Apr 12 2005 cthiel@suse.de
- initial creation of package (4.2.1)
